@@ -302,7 +302,7 @@ class XMLRPC(API):
 
         if delegate is not None:
             patches = []
-            delegate_ids = self._person_ids_by_name(self, delegate)
+            delegate_ids = self._person_ids_by_name(delegate)
             if len(delegate_ids) == 0:
                 sys.stderr.write(
                     "Note: Nobody found matching *%s*\n" % delegate
@@ -371,7 +371,7 @@ class XMLRPC(API):
             params['archived'] = archived == 'yes'
 
         try:
-            return self._client.patch_set(patch_id, params)
+            self._client.patch_set(patch_id, params)
         except xmlrpclib.Fault as f:
             raise exceptions.APIError(
                 'Error updating patch: %s' % f.faultString
@@ -411,7 +411,7 @@ class XMLRPC(API):
         description="",
     ):
         try:
-            return self._client.check_create(
+            self._client.check_create(
                 patch_id,
                 context,
                 state,
@@ -431,7 +431,7 @@ class REST(API):
         parsed_server = urllib.parse.urlparse(server)
         scheme = parsed_server.scheme or 'http'
         hostname = parsed_server.netloc
-        path = parsed_server.path
+        path = parsed_server.path.rstrip('/')
         if path.rstrip('/') == '/xmlrpc':
             path = '/api'
 
@@ -712,6 +712,7 @@ class REST(API):
         archived,
         msgid,
         name,
+        hash,
         max_count=None,
     ):
         # we could implement these but we don't need them
@@ -729,6 +730,9 @@ class REST(API):
         if project is not None:
             filters['project'] = project
 
+        if hash is not None:
+            filters['hash'] = hash
+
         patches = self._list('patches', params=filters)
         return [self._patch_to_dict(patch) for patch in patches]
 
@@ -787,8 +791,7 @@ class REST(API):
         if archived is not None:
             params['archived'] = archived
 
-        patch = self._update('patches', patch_id, params)
-        return self._patch_to_dict(patch)
+        self._update('patches', patch_id, params)
 
     # states
 
@@ -879,7 +882,7 @@ class REST(API):
         target_url="",
         description="",
     ):
-        check = self._create(
+        self._create(
             'patches',
             resource_id=patch_id,
             subresource_type='checks',
@@ -890,8 +893,3 @@ class REST(API):
                 'description': description,
             },
         )
-        patch = self._detail(
-            'patches',
-            patch_id,
-        )
-        return self._check_to_dict(check, patch)
