@@ -619,6 +619,7 @@ def test_list__no_options(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name=None,
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -642,6 +643,7 @@ def test_list__state_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name=None,
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -665,6 +667,7 @@ def test_list__archived_filter(mock_action, mock_api, mock_config):
         archived=True,
         msgid=None,
         name=None,
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -694,6 +697,7 @@ def test_list__project_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name=None,
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -717,6 +721,7 @@ def test_list__submitter_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name=None,
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -740,6 +745,7 @@ def test_list__delegate_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name=None,
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -763,6 +769,7 @@ def test_list__msgid_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid='fakemsgid',
         name=None,
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -786,6 +793,7 @@ def test_list__name_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name='fake patch name',
+        hash=None,
         max_count=None,
         format_str=None,
     )
@@ -809,6 +817,7 @@ def test_list__limit_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name=None,
+        hash=None,
         max_count=5,
         format_str=None,
     )
@@ -832,11 +841,36 @@ def test_list__limit_reverse_filter(mock_action, mock_api, mock_config):
         archived=None,
         msgid=None,
         name=None,
+        hash=None,
         max_count=-5,
         format_str=None,
     )
 
 
+@mock.patch.object(utils.configparser, 'ConfigParser')
+@mock.patch.object(api, 'XMLRPC')
+@mock.patch.object(patches, 'action_list')
+def test_list__hash_filter(mock_action, mock_api, mock_config):
+
+    mock_config.return_value = FakeConfig()
+
+    shell.main(['list', '-H', '3143a71a9d33f4f12b4469818d205125cace6535'])
+
+    mock_action.assert_called_once_with(
+        mock_api.return_value,
+        project=DEFAULT_PROJECT,
+        submitter=None,
+        delegate=None,
+        state=None,
+        archived=None,
+        msgid=None,
+        name=None,
+        hash='3143a71a9d33f4f12b4469818d205125cace6535',
+        max_count=None,
+        format_str=None,
+    )
+
+
 @mock.patch.object(utils.configparser, 'ConfigParser')
 @mock.patch.object(api, 'XMLRPC')
 @mock.patch.object(projects, 'action_list')
